#
# spec file for package perl-Test-Spelling
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Test-Spelling
Version:        0.25
Release:        bp155.2.8
%define cpan_name Test-Spelling
Summary:        Check for spelling errors in POD files
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/C/CA/CAPOEIRAB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IPC::Run3)
BuildRequires:  perl(Pod::Spell)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Tester)
Requires:       perl(IPC::Run3)
Requires:       perl(Pod::Spell)
%{perl_requires}

%description
Test::Spelling lets you check the spelling of a 'POD' file, and report its
results in standard Test::More fashion. This module requires a spellcheck
program such as at http://hunspell.github.io/, _aspell_, _spell_, or,
_ispell_. We suggest using Hunspell.

    use Test::Spelling;
    pod_file_spelling_ok('lib/Foo/Bar.pm', 'POD file spelling OK');

Note that it is a bad idea to run spelling tests during an ordinary CPAN
distribution install, or in a package that will run in an uncontrolled
environment. There is no way of predicting whether the word list or
spellcheck program used will give the same results. You *can* include the
test in your distribution, but be sure to run it only for authors of the
module by guarding it in a 'skip_all unless $ENV{AUTHOR_TESTING}' clause,
or by putting the test in your distribution's _xt/author_ directory.
Anyway, people installing your module really do not need to run such tests,
as it is unlikely that the documentation will acquire typos while in
transit.

You can add your own stop words, which are words that should be ignored by
the spell check, like so:

    add_stopwords(qw(asdf thiswordiscorrect));

Adding stop words in this fashion affects all files checked for the
remainder of the test script. See Pod::Spell (which this module is built
upon) for a variety of ways to add per-file stop words to each .pm file.

If you have a lot of stop words, it's useful to put them in your test
file's 'DATA' section like so:

    use strict;
    use warnings;
    use Test::More;

    use Test::Spelling;
    use Pod::Wordlist;

    add_stopwords(<DATA>);
    all_pod_files_spelling_ok();

    __DATA__
    folksonomy
    Jifty
    Zakirov

To maintain backwards compatibility, comment markers and some whitespace
are ignored. In the near future, the preprocessing we do on the arguments
to Test::Spelling/"add_stopwords" will be changed and documented properly.

%prep
%setup -q -n %{cpan_name}-%{version}
# MANUAL BEGIN
sed -i -e 's/use inc::Module::Install/use lib q[.];\nuse inc::Module::Install/' Makefile.PL
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Wed May 29 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.25
  see /usr/share/doc/packages/perl-Test-Spelling/Changes
  0.25      2019-05-28
  - Re-worded the documentation.
  - Ordered documented function in alphabetical order.
  - Fixed up the synopsis.
  - Put function usage examples directly below the function name; this
    makes it easier to get clickable links for functions in metacpan
  - Documented get_pod_parser
  - Moved hunspell up to the preferred checker
* Sat May 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.24
  see /usr/share/doc/packages/perl-Test-Spelling/Changes
  0.24      2019-05-24
  - Fixup the prereqs some
  - Revert the unicode support added in the last release as it caused
    some test breakage
* Wed May 22 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.23
  see /usr/share/doc/packages/perl-Test-Spelling/Changes
  0.23      2019-05-21
  - Fixed some documentation errors (Mohammad S Anwar)
  - Added unicode support (Kivanc Yazan, GH PR#10)
  - Bump Perl prereq to 5.8 now that we support unicode
  - Don't inherit from Exporter (Olivier Mengué, GH PR#9)
  - Bump Exporter prereq to 5.57
* Thu Apr 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.22
  see /usr/share/doc/packages/perl-Test-Spelling/Changes
  0.22      2019-04-24
  - Zero-code-change release encompassing everything from 0.21
  - Resolves RT#120425 . in @INC should no longer be an issue
  0.21      2019-04-19 (TRIAL)
  - Removed the POD spelling test from /t as it's now in /xt
  - Forego usage of inc::Module::Install for EU::MM
  - List out all prereqs individually; provide cpanfile
  - Use dzil to build the dist
  - Convert the README to markdown
  - Add a LICENSE file
  - Clean up the Changes log
* Tue Oct  3 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Sat Feb  7 2015 coolo@suse.com
- updated to 0.20
  - Add a sorted list of your most commonly misspelled words to
    the end of all_pod_files_spelling_ok to aid stopword list creation
    and bulk correction. (Kent Fredric)
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.19
  - for more consistent results avoid using the user's local aspell
    dictionary [rt.cpan.org #56483] (Karen Etheridge)
  - Work around Pod::Spell limitations (David Golden)
  - Improve case handling (David Golden)
  - Improve test failure reporting (Karen Etheridge)
  - Include more useful info in Test-Spelling's own test
    suite (Shawn Moore)
  - Use IPC::Run3 instead of IPC::Open3
    Quoth IPC::Open3:
    If you try to read from the child's stdout writer
    and their stderr writer, you'll have problems with
    blocking ... This is very dangerous, as you may
    block forever.
    Also the code is nicely shorter. (Randy Stauner)
  - Allow use of a custom POD parser rather than Pod::Spell
    using set_pod_parser (Thomas Sibley)
* Mon Dec 19 2011 coolo@suse.de
- update to 0.15
  - Begin adding actual tests
    (Hilariously, adding the suggested t/pod-spell.t to this
    dist to test itself found a typo: "stopwards")
  - Fix an error when using add_stopwords("constant", "strings")
    [rt.cpan.org #68471] (reported by Nicholas Bamber)
  - Make alternatives checking more robust by reading the spellchecker's
    STDERR
  - Best Practical has taken over maintainership of this module
  - Try various spellcheck programs instead of hardcoding the ancient
    `spell` [rt.cpan.org #56483] (reported by Lars Dɪᴇᴄᴋᴏᴡ, et al)
  - Remove temporary files more aggressively [rt.cpan.org #41586]
    (reported by Tokuhiro Matsuno)
  - fixed by not creating them at all :) instead we now use IPC::Open3
  - Remove suggestion to use broken `aspell -l` [rt.cpan.org #28967]
    (reported by David Hand)
  - Add set_pod_file_filter for skipping translations, etc.
  - Skip tests in all_pod_files_spelling_ok if there is no working
    spellchecker
  - Provide a has_working_spellchecker so you can skip your own tests if
    there's no working spellchecker
  - Switch to Module::Install
  - Rewrite and modernize a lot of the documentation
  - Decruftify code, such as by using Exporter and lexical filehandles
  - Support .plx files (you're welcome Schwern)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Aug 27 2010 pascal.bleser@opensuse.org
- initial package (0.11)
